package com.ys.bdtp.adm.mvvm.ui.screen.offline

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.runtime.*
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalLifecycleOwner
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.lifecycle.Lifecycle
import androidx.lifecycle.flowWithLifecycle
import com.ys.bdtp.adm.mvvm.model.Data
import com.ys.bdtp.adm.mvvm.ui.compose.Head
import com.ys.bdtp.adm.mvvm.ui.compose.HeadRight
import com.ys.bdtp.adm.mvvm.ui.compose.LogoutPopup
import com.ys.bdtp.adm.mvvm.ui.screen.main.LocalNavHostController
import com.ys.bdtp.adm.mvvm.ui.screen.main.offlineToLogin
import com.ys.bdtp.adm.mvvm.vm.offline.OfflineViewModel
import kotlinx.coroutines.launch
import org.kodein.di.compose.rememberViewModel

@Composable
fun Offline(projectId: String) {
    val nav = LocalNavHostController.current!!
    val vm by rememberViewModel<OfflineViewModel>()
    val scope = rememberCoroutineScope()
    var popupState by remember { mutableStateOf(false) }

    val lifecycleOwner = LocalLifecycleOwner.current
    val lifecycleWare = remember(lifecycleOwner) {
        vm.getProjectWithBuildingsById(projectId).flowWithLifecycle(lifecycleOwner.lifecycle, Lifecycle.State.STARTED)
    }
    val projectsState = lifecycleWare.collectAsState(Data.loading())

    Column(modifier = Modifier.background(Color.White)) {
        Head(
            left = {
                OfflineHeadLeft(back = { nav.navigateUp() })
            },
            right = {
                HeadRight(
                    role = { "业务角色" },
                    click = {
                        popupState = !popupState
                    }
                )
            }
        )

        if (popupState) {
            LogoutPopup(
                click = {
                    scope.launch {
                        vm.logout()
                    }
                    popupState = false
                    nav.offlineToLogin()
                }
            )
        }

        Spacer(
            modifier = Modifier
                .height(1.dp)
                .fillMaxWidth()
                .background(Color(0xFFEFF0F1))
        )

        Row {
            OfflineSide(projectsState)
            Spacer(
                modifier = Modifier
                    .width(1.dp)
                    .fillMaxHeight()
                    .background(Color(0xFFEFF0F1))
            )
            Column(
                modifier = Modifier
                    .fillMaxSize()
                    .padding(horizontal = 32.dp, vertical = 12.dp)
            ) {
                OfflineContent()
            }
        }

    }
}

@Preview(widthDp = 1137, heightDp = 711)
@Composable
fun PreviewOfflineScreen() {
    //Offline()
}