package com.ys.bdtp.adm.mvvm.ui.screen.offline

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.*
import androidx.compose.material.Button
import androidx.compose.material.ButtonDefaults
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.State
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import com.ys.bdtp.adm.R
import com.ys.bdtp.adm.app.theme.bgBlueColor
import com.ys.bdtp.adm.app.theme.underColor
import com.ys.bdtp.adm.app.theme.whiteColor
import com.ys.bdtp.adm.mvvm.model.Data
import com.ys.bdtp.adm.mvvm.model.db.relation.ProjectWithBuildings
import com.ys.bdtp.adm.mvvm.model.vo.request.requestBody
import com.ys.bdtp.adm.mvvm.ui.compose.Div
import com.ys.bdtp.adm.mvvm.vm.offline.OfflineViewModel
import kotlinx.coroutines.launch
import org.kodein.di.compose.rememberViewModel


/**
 * 离线数据左侧UI
 */
@Composable
fun OfflineSide(state: State<Data<ProjectWithBuildings>>) {
    val vm by rememberViewModel<OfflineViewModel>()
    val scope = rememberCoroutineScope()
    val projectsState = remember { state }

    Column(
        modifier = Modifier
            .width(280.dp)
            .fillMaxHeight()
            .background(underColor)
            .padding(vertical = 30.dp),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {

        Button(
            modifier = Modifier.size(220.dp, 42.dp),
            onClick = {
                scope.launch {
                    // 下载字典
                    val data = projectsState.value.data
                    data?.project?.let {
                        vm.getDict(
                            body = requestBody(
                                userId = it.userId,
                                groupCode = it.groupCode,
                                projectId = it.projectId,
                            ),
                            success = {
                                println("success: $it")
                            },
                            failure = {
                                println("failure: $it")
                            }
                        )
                    }
                }
                scope.launch {
                    // 下载配置
                    val data = projectsState.value.data
                    data?.project?.let {
                        vm.getConfig(
                            body = requestBody(
                                userId = it.userId,
                                groupCode = it.groupCode,
                                projectId = it.projectId,
                            ),
                            success = {
                                println("success: $it")
                            },
                            failure = {
                                println("failure: $it")
                            }
                        )
                    }
                }
                scope.launch {
                    // 下载建筑与楼层数据
                    val data = projectsState.value.data
                    val project = data?.project
                    vm.getBuildingsAndFloors(
                        body = requestBody(
                            userId = project?.userId ?: "",
                            groupCode = project?.groupCode ?: "",
                            projectId = project?.projectId ?: "",
                        ),
                        success = {
                            println("success: $it")
                        },
                        failure = {
                            println("failure: $it")
                        }
                    )
                }
                scope.launch {
                    // 任务数据
                    // 需要单独隔离出来
                    val data = projectsState.value.data
                    val project = data?.project
                    val buildings = data?.buildings
                    buildings?.forEach { building ->
                        vm.getMission(
                            body = requestBody(
                                userId = project?.userId ?: "",
                                groupCode = project?.groupCode ?: "",
                                projectId = project?.projectId ?: "",
                                buildingId = building.id
                            ),
                            success = {
                                println("success: ")
                            },
                            failure = {
                                println("failure: $it")
                            }
                        )
                    }
                }
            },
            colors = ButtonDefaults.buttonColors(
                contentColor = whiteColor,
                backgroundColor = bgBlueColor
            ),
            elevation = ButtonDefaults.elevation(0.dp)
        ) {
            Text(text = "全部同步")
        }

        Spacer(modifier = Modifier.fillMaxWidth().height(25.dp))
        Div(Div.Row)
        Spacer(modifier = Modifier.fillMaxWidth().height(10.dp))

        // 项目任务
        Column(
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Row(
                modifier = Modifier
                    .width(216.dp)
                    .height(60.dp)
                    .clickable {

                    },
                verticalAlignment = Alignment.CenterVertically
            ) {
                Spacer(modifier = Modifier.width(16.dp))
                Image(
                    painter = painterResource(R.drawable.red_circle),
                    contentDescription = "",
                    modifier = Modifier.size(8.dp)
                )
                Spacer(modifier = Modifier.width(12.dp))
                Text(text = "项目任务")
            }

            // 工程数据
            Row(
                modifier = Modifier
                    .width(216.dp)
                    .height(60.dp)
                    .clickable {

                    },
                verticalAlignment = Alignment.CenterVertically
            ) {
                Spacer(modifier = Modifier.width(16.dp))
                Image(
                    painter = painterResource(R.drawable.red_circle),
                    contentDescription = "",
                    modifier = Modifier.size(8.dp)
                )
                Spacer(modifier = Modifier.width(12.dp))
                Text(text = "工程数据")
            }

            // 楼层模型
            Row(
                modifier = Modifier
                    .width(216.dp)
                    .height(60.dp)
                    .clickable {

                    },
                verticalAlignment = Alignment.CenterVertically
            ) {
                Spacer(modifier = Modifier.width(16.dp))
                Image(
                    painter = painterResource(R.drawable.red_circle),
                    contentDescription = "",
                    modifier = Modifier.size(8.dp)
                )
                Spacer(modifier = Modifier.width(12.dp))
                Text(text = "楼层模型")
            }

            // 参考图纸
            Row(
                modifier = Modifier
                    .width(216.dp)
                    .height(60.dp)
                    .clickable {

                    },
                verticalAlignment = Alignment.CenterVertically
            ) {
                Spacer(modifier = Modifier.width(16.dp))
                Image(
                    painter = painterResource(R.drawable.red_circle),
                    contentDescription = "",
                    modifier = Modifier.size(8.dp)
                )
                Spacer(modifier = Modifier.width(12.dp))
                Text(text = "参考图纸")
            }

            // 交付范围
            Row(
                modifier = Modifier
                    .width(216.dp)
                    .height(60.dp)
                    .clickable {

                    },
                verticalAlignment = Alignment.CenterVertically
            ) {
                Spacer(modifier = Modifier.width(16.dp))
                Image(
                    painter = painterResource(R.drawable.red_circle),
                    contentDescription = "",
                    modifier = Modifier.size(8.dp)
                )
                Spacer(modifier = Modifier.width(12.dp))
                Text(text = "交付范围")
            }

            // 交付规则
            Row(
                modifier = Modifier
                    .width(216.dp)
                    .height(60.dp)
                    .clickable {

                    },
                verticalAlignment = Alignment.CenterVertically
            ) {
                Spacer(modifier = Modifier.width(16.dp))
                Image(
                    painter = painterResource(R.drawable.red_circle),
                    contentDescription = "",
                    modifier = Modifier.size(8.dp)
                )
                Spacer(modifier = Modifier.width(12.dp))
                Text(text = "交付规则")
            }
        }
    }
}

@Preview
@Composable
fun PreviewOfflineSide() {
    // OfflineSide(projectsState)
}