package com.ys.bdtp.adm.mvvm.vm.cad

import com.ys.bdtp.adm.mvvm.model.Data
import com.ys.bdtp.adm.mvvm.model.db.AdmDatabase
import com.ys.bdtp.adm.mvvm.model.db.relation.FloorWithCads
import com.ys.bdtp.adm.mvvm.model.db.relation.BuildingWithFloors
import com.ys.bdtp.adm.mvvm.model.db.relation.ProjectWithBuildingAndFloors
import com.ys.bdtp.adm.mvvm.model.nt.Api
import com.ys.bdtp.adm.mvvm.model.toStateFlow
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.collect
import kotlinx.coroutines.withContext


class CadRepository(private val api: Api, private val db: AdmDatabase) {


    /**
     * 获取项目以及项目下的建筑和楼层
     */
    /* fun getProjectWithBuildingAndFloors(id: String): Flow<Data<ProjectWithBuildingAndFloors>> {
         return db.projectDao().getProjectWithBuildingAndFloorsById(id).toStateFlow()
     }*/

    suspend fun getProject(id: String): ProjectWithBuildingAndFloors {
        return withContext(Dispatchers.IO) {
            db.projectDao().getProjectWithBuildingAndFloorsById(id)
        }
    }

    suspend fun getFloorWithCads(id: String): FloorWithCads {
        return withContext(Dispatchers.IO) {
            db.floorDao().getFloorWithCadsById(id)
        }
    }


    suspend fun logout() {
        withContext(Dispatchers.IO) {
            db.userDao().getUser().collect {
                it?.let {
                    it.state = 0
                    db.userDao().updUser(it)
                }
            }
        }
    }


}
